@@ -20,11 +20,11 @@ from .mixin import NodeListenerMixin
 
 Bot = Union[discord.Client, discord.AutoShardedClient, commands.Bot, commands.AutoShardedBot]
 
-__all__: list = [
+__all__: tuple = (
     'Player',
     'Protocol',
     'PresetPlayer'
-]
+)
 
 __log__: logging.Logger = logging.getLogger('obsidian.player')
 
@@ -106,9 +106,20 @@ class Protocol(discord.VoiceProtocol, ABC):
         await self.player.set_pause(False)
 
 
-class Player:
-    """
-    Represents a guild's player.
+class Player(NodeListenerMixin):
+    """Represents a guild's music player.
+
+    This class is recommended to be subclassed for custom behaviors.
+    This class also inherits from :class:`.NodeListenerMixin`.
+
+    Parameters
+    ----------
+    node: :class:`.BaseNode`
+        The node constructing this player.
+    bot: :class:`discord.Client`
+        The bot of the corresponding node.
+    guild: Union[:class:`discord.Guild`, :class:`discord.Object`]
+        The guild that this player corresponds to.
     """
 
     def __init__(self, node, bot: Bot, guild: Union[discord.Guild, discord.Object]) -> None:
@@ -148,71 +159,88 @@ class Player:
 
     @property
     def bot(self) -> Bot:
+        """:class:`discord.Client` The bot that this player uses."""
         return self._bot
 
     @property
     def guild(self) -> Union[discord.Guild, discord.Object]:
+        """Union[:class:`discord.Guild`, :class:`discord.Object`]: The guild that corresponds to this player."""
         return self._guild
 
     @property
     def guild_id(self) -> int:
+        """int: The ID of the guild that corresponds to this player."""
         return self._guild.id
 
     @property
     def channel(self) -> discord.VoiceChannel:
+        """:class:`discord.VoiceChannel`: The voice channel that this player is connected to."""
         return self._channel
 
     @property
     def node(self):
+        """:class:`.Node`: The node that this player uses."""
         return self._node
 
     @property
     def current(self) -> Track:
+        """:class:`.Track`: The current track this player is playing."""
         return self._current
 
     @property
     def connected(self) -> bool:
+        """bool: Whether or not this player is connected."""
         return self._channel is not None
 
     @property
     def playing(self) -> bool:
+        """
+        Whether or not this player is playing music.
+        """
         return self.connected and self._current is not None
 
     @property
     def paused(self) -> bool:
+        """bool: Whether or not this player is paused."""
         return self._paused
 
     @property
     def current_track_id(self) -> Optional[str]:
+        """Optional[str]: The raw base 64 ID of the current track playing."""
         return self._current_track_id
 
     @property
     def voice_client(self) -> Protocol:
+        """:class:`.Protocol`: The :class:`.Protocol` this player is currently using."""
         return self.__protocol
 
     @property
     def filters(self) -> FilterSink:
+        """:class:`.FilterSink`: The :class:`.FilterSink` of filters this player is using."""
         return self.__sink
 
     @filters.setter
     def filters(self, sink: FilterSink) -> None:
         if not isinstance(sink, FilterSink):
-            raise TypeError('Filter sinks must inherit from FitlerSink.')
+            raise TypeError('Filter sinks must inherit from FilterSink.')
 
         self.__sink = sink
 
     @property
     def volume(self) -> int:
+        """int: The current volume of the music playing."""
         return self.__sink.volume.percent if self.__sink.volume else 100
 
     @property
     def equalizer(self) -> Optional[Equalizer]:
+        """Optional[:class:`.Equalizer`]: The current equalizer of the music audio."""
         return self.__sink.equalizer
 
     eq = equalizer
 
     @property
     def listeners(self) -> List[discord.Member]:
+        """List[:class:`discord.Member`]: Returns a list of :class:`discord.Member` in the voice channel that are undeafened."""
         if not self._channel:
             return []
 
@@ -223,6 +251,10 @@ class Player:
 
     @property
     def position(self) -> float:
+        """float: The position, in milliseconds, of the current track playing.
+
+        For example, this can return `62000` if the track is 62 seconds in.
+        """
         if not self.is_playing():
             return 0
 
@@ -291,6 +323,27 @@ class Player:
             reconnect: Optional[bool] = None,
             self_deaf: bool = False
     ) -> Protocol:
+        """Connects to a :class:`discord.VoiceChannel`.
+
+        Parameters
+        ----------
+        channel: :class:`discord.VoiceChannel`
+            The channel to connect to.
+        cls: type, default: :class:`.Protocol`
+            The connection protocol class to use.
+        timeout: float, optional
+            The timeout to use when connecting.
+        reconnect: bool, optional
+            Whether or not to reconnect.
+        self_deaf: bool, default: False
+            Whether or not to self-deafen upon connecting.
+
+        Returns
+        -------
+        :class:`.Protocol`
+            The connection protocol created.
+        """
+
         if not issubclass(cls, Protocol):
             raise TypeError('Connection class must inherit from Protocol')
 
@@ -302,18 +355,42 @@ class Player:
         return self.__protocol
 
     async def disconnect(self, *, force: bool = False) -> None:
+        """Disconnects from the current voice connection.
+
+        Parameters
+        ----------
+        force: bool, default: False
+            Whether or not to force disconnection.
+        """
+
         if not self.__protocol or not self.connected:
             raise ValueError('No connection to disconnect from.')
 
         await self.__protocol.disconnect(force=force)
 
     async def destroy(self, *, force: bool = False) -> None:
+        """Destroys, disconnects, and deletes this player.
+
+        Parameters
+        ----------
+        force: bool, default: False
+            Whether or not to force disconnection.
+        """
+
         await self.disconnect(force=force)
         del self.node._players[self.guild_id]
 
         __log__.info(f'PLAYER | {self.guild_id} has been destroyed.')
 
     async def move(self, channel: discord.VoiceChannel) -> None:
+        """Moves the connection to another voice channel.
+
+        Parameters
+        ----------
+        channel: :class:`discord.VoiceChannel`
+            The channel to move to.
+        """
+
         if not self.__protocol or not self.connected:
             raise ValueError('No connection to move.')
 
@@ -338,6 +415,23 @@ class Player:
             end_time: int = 0,
             no_replace: bool = False
     ) -> None:
+        """Plays a track using this player.
+
+        If you provide a playlist, the player will play the `Playlist.selected_track`.
+
+        Parameters
+        ----------
+        track: :class:`.Track`
+            The track to play.
+        start_time: int, default: 0
+            The start time offset of the track, in milliseconds.
+        end_time: int, default: 0
+            When to end the track, in milliseconds.
+        no_replace: bool, default: False
+            If set to True, this will do nothing if a track is already playing.
+            If set to False, this will overwrite the current playing track.
+        """
+
         if isinstance(track, Playlist):
             track = track.selected_track
 
@@ -367,6 +461,14 @@ class Player:
         self._current = track
 
     async def stop(self, *, force: bool = False) -> None:
+        """Stops the current playing track.
+
+        Parameters
+        ----------
+        force: bool, default: False
+            Whether or not to force stop the track.
+        """
+
         if not self._current and not force:
             return
 
@@ -376,6 +478,20 @@ class Player:
         self._current = None
 
     async def set_pause(self, pause: Optional[bool] = None) -> bool:
+        """Sets the paused state for the current track.
+
+        Parameters
+        ----------
+        pause: bool, optional
+            The new paused state.
+            If this is left as None, the new paused state will be the opposite of the current.
+
+        Returns
+        -------
+        bool
+            The new paused state (for confirmation).
+        """
+
         pause = pause if pause is not None else not self._paused
 
         await self._node.send(OpCode.PLAYER_PAUSE, {'guild_id': str(self._guild.id), 'state': pause})
@@ -385,6 +501,14 @@ class Player:
         return res
 
     async def set_position(self, position: float) -> None:
+        """Sets the current time position, in milliseconds, of the current playing track.
+
+        Parameters
+        ----------
+        position: float
+            The new time position, in milliseconds.
+        """
+
         if not self._current or 0 > position > self._current.length:
             return
 
@@ -395,6 +519,20 @@ class Player:
         self._last_update = time.time() * 1000
 
     async def set_volume(self, volume: int = 100) -> None:
+        """Sets the player volume in percent.
+
+        The volume must be at least 0 and at most 500.
+
+        .. warning::
+            It is recommended not to allow users to set the volume past 200
+            as it is then virtually earrape.
+
+        Parameters
+        ----------
+        volume: int, default: 100
+            The new volume of the player.
+        """
+
         if self.__sink.volume:
             self.__sink.volume.percent = volume
 
@@ -402,6 +540,14 @@ class Player:
         await self.update_filters()
 
     async def set_equalizer(self, equalizer: Equalizer) -> None:
+        """Overwrites and changes the current audio equalizer.
+
+        Parameters
+        ----------
+        equalizer: :class:`.Equalizer`
+            The new equalizer to use.
+        """
+
         self.__sink.add(equalizer)
         await self.update_filters()
 
@@ -410,22 +556,54 @@ class Player:
         __log__.info(f'PLAYER | {self.guild.id} updated filters')
 
     async def set_filters(self, filters: FilterSink) -> None:
+        """Completely overwrites the current filter sink into a new one.
+
+        Parameters
+        ----------
+        filters: :class:`.FilterSink`
+            The new filter sink to use.
+
+        See Also
+        --------
+        :meth:`Player.add_filter`:
+            Appends a new filter to the current filter sink.
+        """
+
         self.filters = filters
         await self.update_filters()
 
     async def add_filter(self, *filters: BaseFilter) -> None:
+        """Appends a new filter, or filters, to the current filter sink.
+
+        Parameters
+        ----------
+        filters: :class:`.BaseFilter`
+            The filter(s) to add.
+        """
+
         for filter_ in filters:
             self.__sink.add(filter_)
 
         await self.update_filters()
 
     async def remove_filter(self, *filters) -> None:
+        """Removes a filter from the current filter sink.
+
+        Parameters
+        ----------
+        filters: :class:`.BaseFilter`
+            The filter(s) to remove.
+        """
+
         for filter_ in filters:
             self.__sink.remove(filter_)
 
         await self.update_filters()
 
     async def reset_filters(self) -> None:
+        """
+        Resets the current filter sink.
+        """
         self.__sink.reset()
         await self.update_filters()
 
@@ -441,7 +619,7 @@ class Player:
     set_eq = set_equalizer
 
 
-class PresetPlayer(Player, NodeListenerMixin):
+class PresetPlayer(Player):
     """Basic music player with many things already built and handled for you.
 
     Note that this class should still be inherited from in order to add required methods.
@@ -479,6 +657,7 @@ class PresetPlayer(Player, NodeListenerMixin):
 
     @property
     def dj(self) -> discord.Member:
+        """:class:`discord.Member`: The current DJ of this player."""
         return self._dj
 
     @dj.setter
@@ -487,18 +666,30 @@ class PresetPlayer(Player, NodeListenerMixin):
 
     @property
     def queue(self) -> Queue:
+        """:class:`.PointerBasedQueue`: The current queue for this player."""
         return self._queue
 
     @property
     def now_playing(self) -> Track:
+        """:class:`.Track`: The current track that is playing."""
         return self._queue.current
 
+    @property
+    def index(self) -> int:
+        """int: The pointer index of the queue."""
+        return self._queue.index
+
     current = now_playing
 
-    async def build_embed(self, embed: discord.Embed) -> None:
-        raise NotImplementedError
-
     def enqueue(self, track: Union[Track, Playlist]) -> None:
+        """Enqueues a :class:`.Track` or an entire :class:`.Playlist`.
+
+        Parameters
+        ----------
+        track: Union[:class:`.Track`, :class:`.Playlist`]
+            The track or playlist to enqueue.
+        """
+
         self._kill_destroy_task()
         self._queue.add(track)
 
@@ -507,6 +698,14 @@ class PresetPlayer(Player, NodeListenerMixin):
         await self.destroy()
 
     def set_loop_type(self, new: LoopType) -> None:
+        """Changes the :class:`.LoopType` of the queue.
+
+        Parameters
+        ----------
+        new: :class:`.LoopType`
+            The new loop type to use.
+        """
+
         self._queue.set_loop_type(new)
 
     def _kill_destroy_task(self) -> None:
@@ -523,7 +722,31 @@ class PresetPlayer(Player, NodeListenerMixin):
         return track
 
     async def do_next(self) -> Optional[Track]:
+        """Plays the track fetched from :meth:`PointerBasedQueue.get`.
+
+        Returns
+        -------
+        Optional[:class:`.Track`]
+            The track that will be played, if any.
+        """
+
         return await self.__play(self._queue.get())
 
     async def skip(self) -> Optional[Track]:
+        """Skips the current track regardless of the loop type.
+
+        This uses :meth:`PointerBasedQueue.skip`.
+
+        Returns
+        -------
+        Optional[:class:`.Track`]
+            The new track to be played, if any.
+        """
+
         return await self.__play(self._queue.skip())
+
+    async def build_embed(self, embed: discord.Embed) -> None:
+        raise NotImplementedError
+
+    async def send_now_playing(self):
+        raise NotImplementedError
